#
# spec file for package thrift
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libversion 0_11_0
%define libname    %{version}
%bcond_without perl
%bcond_without c
%bcond_without python2
%bcond_without python3
%bcond_with java
%bcond_with ruby
%bcond_with qt5
Name:           thrift
Version:        0.11.0
Release:        1.3
Summary:        Framework for scalable cross-language services development
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            https://thrift.apache.org
Source0:        https://www.apache.org/dist/thrift/%{version}/%{name}-%{version}.tar.gz
Source1:        https://www.apache.org/dist/thrift/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(openssl)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
%endif
%if %{with python2}
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(python2)
%endif
%if %{with python3}
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(python3)
%endif
%if %{with c}
BuildRequires:  pkgconfig(glib-2.0)
%endif
%if %{with java}
BuildRequires:  ant
BuildRequires:  java-devel
%endif
%if %{with ruby}
BuildRequires:  ruby-devel
BuildRequires:  rubygem(bundler)
%endif
%if %{with perl}
BuildRequires:  perl
BuildRequires:  perl(Bit::Vector)
BuildRequires:  perl(Class::Accessor)
%endif

%description
Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.

%package -n libthrift-%{libversion}
Summary:        Thrift shared library
Group:          System/Libraries

%description -n libthrift-%{libversion}
Thrift shared library

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.

%post -n libthrift-%{libversion} -p /sbin/ldconfig
%postun -n libthrift-%{libversion} -p /sbin/ldconfig

%package -n libthrift-devel
Summary:        Thrift C++ library development files
Group:          Development/Libraries/C and C++
Requires:       libthrift-%{libversion} = %{version}

%description -n libthrift-devel
Thrift C++ library development files

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.

%if %{with perl}
%package -n perl-thrift
Summary:        Thrift perl library
Group:          Development/Libraries/Perl
%{perl_requires}

%description -n perl-thrift
Thrift perl library

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.
%endif

%if %{with python2}
%package -n python2-thrift
Summary:        Thrift python library
Group:          Development/Libraries/Python
Provides:       python-thrift = %{version}-%{release}
Obsoletes:      python-thrift < %{version}-%{release}

%description -n python2-thrift
Thrift python library

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.
%endif

%if %{with python3}
%package -n python3-thrift
Summary:        Thrift python library
Group:          Development/Libraries/Python

%description -n python3-thrift
Thrift python library

Thrift is a software framework for scalable cross-language services
development. It combines a powerful software stack with a code generation
engine to build services that work efficiently and seamlessly between C++,
Java, C#, Python, Ruby, Perl, PHP, Objective C/Cocoa, Smalltalk, Erlang,
Objective Caml, and Haskell.
%endif

%prep

%setup -q

%build
export CXXFLAGS="%{optflags} -fPIC"

# tests require static boost library
%configure \
	--disable-tests \
	--enable-static=no
make %{?_smp_mflags}

%install
%make_install
pushd compiler/cpp
%make_install
popd
pushd lib/cpp
%make_install
popd

%if %{with python2}
pushd lib/py
make clean
%python2_install
%fdupes %{buildroot}%{python_sitearch}
popd
%endif

%if %{with python3}
pushd lib/py
make clean
%python3_install
%fdupes %{buildroot}%{python_sitearch}
popd
%endif

%if %{with perl}
pushd lib/perl
perl Makefile.PL
%perl_make_install
%perl_process_packlist
mv %{buildroot}%{_prefix}/local/lib/perl5 \
  %{buildroot}%{_perl_vendorlib}
popd
%endif

find %{buildroot} -type f -name "*.la" -delete -print

%files
%defattr(-,root,root)
%doc CHANGES LICENSE NOTICE
%{_bindir}/thrift

%files -n libthrift-%{libversion}
%defattr(-,root,root)
%{_libdir}/libthrift-*.so
%{_libdir}/libthriftnb-*.so
%{_libdir}/libthriftz-*.so
%{_libdir}/libthrift_c_glib.so.*

%files -n libthrift-devel
%defattr(-,root,root)
%{_includedir}/thrift
%{_libdir}/libthrift.so
%{_libdir}/libthriftnb.so
%{_libdir}/libthriftz.so
%{_libdir}/libthrift_c_glib.so
%{_libdir}/pkgconfig/*.pc

%if %{with perl}
%files -n perl-thrift
%defattr(-,root,root)
%{perl_vendorlib}/Thrift.pm
%{perl_vendorlib}/Thrift
%endif

%if %{with python2}
%files -n python2-thrift
%defattr(-,root,root)
%{python_sitearch}/*
%endif

%if %{with python3}
%files -n python3-thrift
%defattr(-,root,root)
%{python3_sitearch}/*
%endif

%changelog
* Fri May  4 2018 mrostecki@suse.com
- Update to 0.11.0:
  https://github.com/apache/thrift/blob/master/CHANGES#L10-L297
* Fri Nov 10 2017 mpluskal@suse.com
- Enable python3 support as well
- Use naming of python subpackages that is consistent with current
  Factory conventions
* Wed Jun 14 2017 mpluskal@suse.com
- Update to version 0.10.0:
  * lots of changes, see provided CHANGES for details
  * fixes building with recent openss (boo#1042675)
- Switch from qt4 to qt5
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Mon Jun 13 2016 mpluskal@suse.com
- Fix a typo in changelog
* Sat Apr 16 2016 mpluskal@suse.com
- Update to 0.9.3
  * numerous changes, see provided CHANGES for details
* Thu Mar  5 2015 mpluskal@suse.com
- Simplify buildconditions
* Mon Mar  2 2015 mpluskal@suse.com
- Disable building of static library
- Do not manually set LDFLAGS
* Mon Mar  2 2015 mpluskal@suse.com
- Remove obsolete patches
  * 0001-Add-missing-limits-header.patch
  * 0002-TNonblockingServer-TLibEventTransport.patch
  * 0003-TDenseProtocol.patch
- Update library name to match shlib naming policy
- Update to 0.9.2
  * numerous changes, see provide CHANGES for details
* Sat Feb 22 2014 opensuse@dstoecker.de
- enable perl and python packages
- remove extension patches
* Thu Feb 20 2014 opensuse@dstoecker.de
- update to 0.9.1
* Wed Sep 25 2013 d.desai@rtsgroup.net
- number of bytes written to transport and number of bytes
  returned from write() method was not same. Fixed this
  problem in TDenseProtocol.
* Thu Aug 15 2013 o.herrmann217@googlemail.com
- Extended 0002-TNonblockingServer-TLibEventTransport.patch to
  properly close TConnection when a client disconnects while
  still receiving updates from libevent.
* Wed Aug  7 2013 d.desai@rtsgroup.net
- Fixed multiple crashes in TNonblockingServer to work with lib_event.
* Fri Jun 21 2013 o.herrmann217@googlemail.com
- Changed 0002-TNonblockingServer-TLibEventTransport.patch to
  install new header file with automake.
* Thu Jun 20 2013 o.herrmann217@googlemail.com
- Replaced std::tr1::bind with boost::bind in TNonblockingServer
  to fix compilation error on RHEL 5.
* Thu Jun 20 2013 o.herrmann217@googlemail.com
- Removed BuildRequires for boost-static
* Thu Jun 20 2013 o.herrmann217@googlemail.com
- Created new patch for integrating external libevent clients in
  TNonblockingServer.
- Removed 0003-TNonblokingServer-release-handler-on-close.patch.
  It is now part of 0002-TNonblockingServer-TLibEventTransport.patch
* Tue May 14 2013 d.desai@rtsgroup.net
- Reverted changes for dependency of openssl for sles_11.
* Tue May 14 2013 d.desai@rtsgroup.net
- Added dependency of openssl for sles_11.
* Mon May 13 2013 d.desai@rtsgroup.net
- Created patch 0003 to release handler on close in
  TNonblockingServer
* Thu May  9 2013 o.herrmann217@googlemail.com
- Fixed reset of smart pointer in patch 0002
* Thu May  9 2013 o.herrmann217@googlemail.com
- Created patch 0002 to access event_base from libevent in
  TNonblockingServer
* Wed Jan 23 2013 d.desai@rtsgroup.net
- Removed boost version
* Wed Jan 23 2013 o.herrmann217@googlemail.com
- Build with --hash-style=sysv
* Sun Dec  2 2012 o.herrmann217@googlemail.com
- Striped one directory in patch 0001
* Sun Dec  2 2012 o.herrmann217@googlemail.com
- Patch for missing limit headers
* Sun Dec  2 2012 o.herrmann217@googlemail.com
- Call make with -j1 to fix compile problem temporally
* Tue Nov 27 2012 jblunck@opensuse.org
- Update to 0.9.0
* Fri Jul 30 2010 dmacvicar@novell.com
- initial package for 0.2.0
